@@ -1,7 +1,7 @@
 /** @file
  * @brief Define preprocessor symbols for the library version
  */
-// Copyright (C) 2002,2004,2005,2006,2007,2008,2009,2010,2011,2012,2013,2015,2016,2017,2018,2020 Olly Betts
+// Copyright (C) 2002-2022 Olly Betts
 //
 // This program is free software; you can redistribute it and/or
 // modify it under the terms of the GNU General Public License as
@@ -24,20 +24,6 @@
 #if __GNUC__ < 3 || (__GNUC__ == 3 && __GNUC_MINOR__ == 0)
 #error Xapian no longer supports GCC < 3.1
 #else
-#if !defined(__GXX_ABI_VERSION) || __GXX_ABI_VERSION != 1016
-#if defined __GXX_ABI_VERSION && __GXX_ABI_VERSION >= 1002
-#warning The C++ ABI version of compiler you are using does not exactly match
-#warning that of the compiler used to build the library. If linking fails
-#warning due to missing symbols, this is probably the reason why.
-#warning The Xapian library was built with g++ 11.2.0
-#else
-#error The C++ ABI version of compiler you are using does not match
-#error that of the compiler used to build the library. The versions
-#error must match or your program will not work correctly.
-#error The Xapian library was built with g++ 11.2.0
-#endif
-#endif
-
 #ifdef _GLIBCXX_DEBUG
 #error You are compiling with _GLIBCXX_DEBUG defined, but the library
 #error was not compiled with this flag. The settings must match or your
@@ -50,7 +36,7 @@
 #define XAPIAN_ENABLE_VISIBILITY
 
 /// The version of Xapian as a C string literal.
-#define XAPIAN_VERSION "1.4.19"
+#define XAPIAN_VERSION "1.4.21"
 
 /** The major component of the Xapian version.
  * E.g. for Xapian 1.0.14 this would be: 1
@@ -65,7 +51,7 @@
 /** The revision component of the Xapian version.
  * E.g. for Xapian 1.0.14 this would be: 14
  */
-#define XAPIAN_REVISION 19
+#define XAPIAN_REVISION 21
 
 /// Base (signed) type for Xapian::docid and related types.
 #define XAPIAN_DOCID_BASE_TYPE int
